"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.compile = exports.run = exports.parse = void 0;
const parser_1 = require("./parser");
const runner_1 = require("./runner");
const utils_1 = require("./utils");
class Bigodon {
    constructor() {
        this.helpers = new Map();
        /** Parses a template and returns an AST representing it. This can be persisted as JSON for later usage. */
        this.parse = (template) => {
            (0, utils_1.ensure)(typeof template === 'string', 'Template must be a string');
            return parser_1.$template.parse(template);
        };
        /** Runs an AST returned by the {@link Bigodon#parse} method. */
        this.run = async (ast, context, options) => {
            return await (0, runner_1.run)(ast, context, this.helpers, options);
        };
        /** Compiles a template and returns a function that, when called, executes it */
        this.compile = (template) => {
            const ast = this.parse(template);
            return (context, options) => this.run(ast, context, options);
        };
        this.addHelper = (name, helper) => {
            (0, utils_1.ensure)(typeof name === 'string', 'name must be a string');
            (0, utils_1.ensure)(typeof helper === 'function', 'helper must be a function');
            this.helpers.set(name, helper);
            return this;
        };
    }
}
const defaultBigodon = new Bigodon();
/** Parses a template and returns an AST representing it. This can be persisted as JSON for later usage. */
exports.parse = defaultBigodon.parse;
/** Runs an AST returned by the {@link parse} method. */
exports.run = defaultBigodon.run;
/** Compiles a template and returns a function that, when called, executes it */
exports.compile = defaultBigodon.compile;
exports.default = Bigodon;
