"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.runHelperExpression = void 0;
const index_1 = require("./index");
const helpers_1 = require("./helpers");
const utils_1 = require("../utils");
async function runHelperExpression(execution, expression) {
    const helperName = expression.path;
    if (utils_1.UNSAFE_KEYS.has(helperName)) {
        throw new Error(`Helper ${helperName} not allowed`);
    }
    const fn = execution.extraHelpers.get(helperName) || helpers_1.helpers[helperName];
    if (!fn) {
        throw new Error(`Helper ${helperName} not found`);
    }
    const paramsTasks = expression.params.map(p => (0, index_1.runStatement)(execution, p));
    const params = await Promise.all(paramsTasks);
    const result = await fn.apply(execution, params);
    return result;
}
exports.runHelperExpression = runHelperExpression;
